# MIMOSA: Integrated Assessment Model for Cost-Benefit Analysis
[![](https://utrechtuniversity.github.io/mimosa/assets/logos/MIMOSA.svg)](https://utrechtuniversity.github.io/mimosa)



MIMOSA is an Integrated Assessment Model (IAM) part of the [IMAGE family](https://www.pbl.nl/en/image/home), with 26 regions covering the whole world. It is a relatively simple Cost-Benefit IAM that still covers the relevant technological and socio-economic dynamics. The climate impacts are calculated using state-of-the-art COACCH damage functions, and the mitigation costs have been directly calibrated to the IPCC AR6 WGIII database.

<a href="https://utrechtuniversity.github.io/mimosa/"><img src="https://img.shields.io/badge/Model%20documentation%20>-8aa042?style=flat-square" height="30"></a>
<a href="https://utrechtuniversity.github.io/mimosa/installation/"><img src="https://img.shields.io/badge/Installation%20instructions%20>-8aa042?style=flat-square" height="30"></a>
<a href="https://utrechtuniversity.github.io/mimosa/run/"><img src="https://img.shields.io/badge/Running%20MIMOSA>-8aa042?style=flat-square" height="30"></a>

MIMOSA is being developed at the [Copernicus Institute of Sustainable Development](https://www.uu.nl/en/research/copernicus-institute-of-sustainable-development) at Utrecht University, and is part of the [IMAGE modelling framework](https://www.pbl.nl/en/image/home).

[<img src="https://utrechtuniversity.github.io/mimosa/assets/logos/UU_logo_2021_EN_RGB.png" width="40%">](https://www.uu.nl/en/research/copernicus-institute-of-sustainable-development)
[<img src="https://utrechtuniversity.github.io/mimosa/assets/logos/IMAGE.png" width="40%">](https://www.pbl.nl/en/image/home)
